export type YoutubeState = "UNSTARTED" | "ENDED" | "PLAYING" | "PAUSED" | "BUFFERING" | "CUED"

export const parseYoutubeState = (playerState: number) => {
  if (playerState === -1) return "UNSTARTED"
  else if (playerState === 0) return "ENDED"
  else if (playerState === 1) return "PLAYING"
  else if (playerState === 2) return "PAUSED"
  else if (playerState === 3) return "BUFFERING"
  else if (playerState === 4) return "CUED"
  else return "UNSTARTED"
}

// Youtube script 초기화 여부를 판단하기 위해 사용함.
let youtubeCreated = 0

export const increaseYoutubeCreated = () => youtubeCreated++

export const youtubeCreatedCount = () => youtubeCreated

// window.YT 가 초기화되었는지 주기적으로 확인하기 위해 사용.
// 다른 곳에도 필요한 경우가 있다면, 별도 util 분리하는 것이 좋다.
export const waitUntil = async (condition: () => boolean, intervalMilliseconds = 200, maxTrial = 15): Promise<void> => {
  return await new Promise(resolve => {
    let tried = 0
    const interval = setInterval(() => {
      if ((tried > maxTrial) || condition()) {
        clearInterval(interval)
        resolve(undefined)
      }
      tried++
    }, intervalMilliseconds)
  })
}
